// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KCALUTILS_VERSION_H
#define KCALUTILS_VERSION_H

#define KCALUTILS_VERSION_STRING "5.24.0"
#define KCALUTILS_VERSION_MAJOR 5
#define KCALUTILS_VERSION_MINOR 24
#define KCALUTILS_VERSION_PATCH 0
#define KCALUTILS_VERSION ((5<<16)|(24<<8)|(0))

#endif
